@@ -446,9 +446,10 @@ def exportResult(result, outputFolder, network, address, typeOf):
             else:
                 sourceCode = json.loads(sourceCode)
             for key in sourceCode.keys():
-                contractName = key.split(".")[0] + ".sol"
+                contractName = key
+                # print(contractName)
                 while os.path.exists(contractFolder + "//" + contractName):
-                    contractName = key.split(".")[0] + "_{}".format(index) + ".sol"
+                    contractName = key.split(".sol")[0] + "_{}".format(index) + ".sol"
                     index += 1
                 index = 0
                 mkdir(os.path.split(contractFolder + "//" + contractName)[0])
@@ -461,7 +462,7 @@ def exportResult(result, outputFolder, network, address, typeOf):
                 return
             contractFolder = defaultFolder if outputFolder == "" else outputFolder
             mkdir(contractFolder)
-            contractName = contractName + ".sol"
+            contractName = contractName
             while os.path.exists(contractFolder + "//" + contractName):
                 contractName = result['ContractName'] + "_{}".format(index) + ".sol"
                 index += 1
